@@ -1,31 +1,24 @@
 import contextlib
 import subprocess
-import importlib.resources as res
 
 import path
 import autocommand
 from more_itertools import consume
 
-
-def resolve(name):
-    return 'jaraco/' * ('/' not in name) + name
+from . import git
 
 
 @contextlib.contextmanager
-def checkout(project):
-    url = f'gh://{project}'
+def temp_checkout(project):
     with path.TempDir() as dir:
-        repo = dir / 'repo'
-        repo.mkdir()
-        subprocess.check_call(['git', 'clone', url, repo])
+        repo = git.checkout(project, dir)
         with repo:
             yield
 
 
 def update_project(name):
-    resolved = resolve(name)
     print('\nupdating', name)
-    with checkout(resolved):
+    with temp_checkout(name):
         proc = subprocess.Popen(['git', 'pull', 'gh://jaraco/skeleton'])
         code = proc.wait()
         if code:
@@ -36,6 +29,4 @@ def update_project(name):
 
 @autocommand.autocommand(__name__)
 def main():
-    source = res.files('jaraco.develop').joinpath('projects.txt')
-    projects = source.read_text().split()
-    consume(map(update_project, projects))
+    consume(map(update_project, git.projects()))
